==> carbon-component-mapper-3.13.0.tgz: package/esm/field-array/field-array.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
var _excluded = ["remove"],
    _excluded2 = ["remove"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { memo } from 'react';
import PropTypes from 'prop-types';
import isEqual from 'lodash/isEqual';
import clsx from 'clsx';
import { createUseStyles } from "react-jss/dist/react-jss.esm.js";
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import useFormApi from "@data-driven-forms/react-form-renderer/use-form-api";
import FieldArrayFF from "@data-driven-forms/react-form-renderer/field-array";
import Button from "carbon-components-react/es/components/Button/Button.js";
import FormGroup from "carbon-components-react/es/components/FormGroup/FormGroup.js";
import AddAlt32 from "@carbon/icons-react/es/add--alt/32.js";
import Subtract32 from "@carbon/icons-react/es/subtract/32.js";
import prepareProps from '../prepare-props';
var useStyles = createUseStyles({
  add: {
    marginTop: 16
  },
  addContainer: {
    width: '100%',
    display: 'flex',
    flexDirection: 'row-reverse'
  },
  remove: {
    marginTop: 8,
    marginBottom: 8
  },
  formGroup: {
    '.bx--form__requirements': {
      color: '#da1e28'
    }
  }
});
var ArrayItem = /*#__PURE__*/memo(function (_ref) {
  var remove = _ref.remove,
      fields = _ref.fields,
      name = _ref.name,
      removeText = _ref.removeText,
      buttonDisabled = _ref.buttonDisabled,
      RemoveButtonProps = _ref.RemoveButtonProps,
      ArrayItemProps = _ref.ArrayItemProps;
  var formOptions = useFormApi();

  var _useStyles = useStyles(),
      removeStyle = _useStyles.remove;

  var editedFields = fields.map(function (field) {
    return _objectSpread(_objectSpread({}, field), field.name ? {
      name: "".concat(name, ".").concat(field.name)
    } : {
      name: name
    });
  });
  return /*#__PURE__*/React.createElement("div", ArrayItemProps, formOptions.renderForm(editedFields, formOptions), /*#__PURE__*/React.createElement(Button, _extends({
    disabled: buttonDisabled,
    renderIcon: Subtract32,
    id: "remove-".concat(name),
    kind: "danger",
    onClick: remove
  }, RemoveButtonProps, {
    className: clsx(removeStyle, RemoveButtonProps.className)
  }), removeText));
}, function (_ref2, _ref3) {
  var _prevRemove = _ref2.remove,
      prev = _objectWithoutProperties(_ref2, _excluded);

  var _nextRemove = _ref3.remove,
      next = _objectWithoutProperties(_ref3, _excluded2);

  return isEqual(prev, next);
});
ArrayItem.propTypes = {
  remove: PropTypes.func,
  fields: PropTypes.array,
  name: PropTypes.string,
  removeText: PropTypes.node,
  buttonDisabled: PropTypes.bool,
  RemoveButtonProps: PropTypes.object,
  ArrayItemProps: PropTypes.object
};
ArrayItem.defaultProps = {
  RemoveButtonProps: {},
  ArrayItemProps: {}
};

var FieldArray = function FieldArray(props) {
  var _useFieldApi = useFieldApi(prepareProps(props)),
      AddContainerProps = _useFieldApi.AddContainerProps,
      AddButtonProps = _useFieldApi.AddButtonProps,
      FormGroupProps = _useFieldApi.FormGroupProps,
      WrapperProps = _useFieldApi.WrapperProps,
      ArrayItemProps = _useFieldApi.ArrayItemProps,
      RemoveButtonProps = _useFieldApi.RemoveButtonProps,
      defaultItem = _useFieldApi.defaultItem,
      maxItems = _useFieldApi.maxItems,
      minItems = _useFieldApi.minItems,
      fields = _useFieldApi.fields,
      input = _useFieldApi.input,
      arrayValidator = _useFieldApi.arrayValidator,
      labelText = _useFieldApi.labelText,
      buttonLabels = _useFieldApi.buttonLabels,
      noItemsMessage = _useFieldApi.noItemsMessage,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount;

  var _useStyles2 = useStyles(),
      formGroup = _useStyles2.formGroup,
      addContainer = _useStyles2.addContainer,
      add = _useStyles2.add;

  var buttonLabelsFinal = _objectSpread({
    add: 'Add',
    remove: 'Remove'
  }, buttonLabels);

  var invalid = (meta.touched || validateOnMount) && !Array.isArray(meta.error) && (meta.error || meta.submitError);
  return /*#__PURE__*/React.createElement(FormGroup, _extends({
    legendText: labelText || '',
    invalid: Boolean(invalid),
    message: Boolean(invalid),
    messageText: invalid || ''
  }, FormGroupProps, {
    className: clsx(formGroup, FormGroupProps.className)
  }), /*#__PURE__*/React.createElement(FieldArrayFF, {
    name: input.name,
    validate: arrayValidator
  }, function (fieldArrayProps) {
    return /*#__PURE__*/React.createElement("div", WrapperProps, fieldArrayProps.fields.length === 0 && noItemsMessage, fieldArrayProps.fields.map(function (name, index) {
      return /*#__PURE__*/React.createElement(ArrayItem, {
        removeText: buttonLabelsFinal.remove,
        key: index,
        remove: function remove() {
          return fieldArrayProps.fields.remove(index);
        },
        name: name,
        fields: fields,
        buttonDisabled: minItems >= fieldArrayProps.fields.length,
        ArrayItemProps: ArrayItemProps,
        RemoveButtonProps: RemoveButtonProps
      });
    }), /*#__PURE__*/React.createElement("div", _extends({}, AddContainerProps, {
      className: clsx(addContainer, AddContainerProps.className)
    }), /*#__PURE__*/React.createElement(Button, _extends({
      disabled: fieldArrayProps.fields.length >= maxItems,
      renderIcon: AddAlt32,
      id: "add-".concat(input.name),
      onClick: function onClick() {
        return fieldArrayProps.fields.push(defaultItem);
      }
    }, AddButtonProps, {
      className: clsx(add, AddButtonProps.className)
    }), buttonLabelsFinal.add)));
  }));
};

FieldArray.propTypes = {
  noItemsMessage: PropTypes.node,
  maxItems: PropTypes.number,
  minItems: PropTypes.number,
  buttonLabels: PropTypes.shape({
    add: PropTypes.node,
    remove: PropTypes.node
  }),
  AddContainerProps: PropTypes.object,
  AddButtonProps: PropTypes.object,
  FormGroupProps: PropTypes.object,
  WrapperProps: PropTypes.object,
  ArrayItemProps: PropTypes.object,
  RemoveButtonProps: PropTypes.object,
  defaultItem: PropTypes.any,
  isRequired: PropTypes.bool,
  fields: PropTypes.array
};
FieldArray.defaultProps = {
  noItemsMessage: 'No items',
  maxItems: Infinity,
  minItems: 0,
  AddContainerProps: {},
  AddButtonProps: {},
  FormGroupProps: {},
  WrapperProps: {},
  ArrayItemProps: {},
  RemoveButtonProps: {}
};
export default FieldArray;

==> carbon-component-mapper-3.17.0.tgz: package/esm/field-array/field-array.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
var _excluded = ["remove"],
    _excluded2 = ["remove"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React, { memo } from 'react';
import PropTypes from 'prop-types';
import isEqual from 'lodash/isEqual';
import clsx from 'clsx';
import { createUseStyles } from "react-jss/dist/react-jss.esm.js";
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import useFormApi from "@data-driven-forms/react-form-renderer/use-form-api";
import FieldArrayFF from "@data-driven-forms/react-form-renderer/field-array";
import Button from "carbon-components-react/es/components/Button/Button.js";
import FormGroup from "carbon-components-react/es/components/FormGroup/FormGroup.js";
import AddAlt32 from "@carbon/icons-react/es/add--alt/32.js";
import Subtract32 from "@carbon/icons-react/es/subtract/32.js";
import prepareProps from '../prepare-props';
var useStyles = createUseStyles({
  add: {
    marginTop: 16
  },
  addContainer: {
    width: '100%',
    display: 'flex',
    flexDirection: 'row-reverse'
  },
  remove: {
    marginTop: 8,
    marginBottom: 8
  },
  formGroup: {
    '.bx--form__requirements': {
      color: '#da1e28'
    }
  }
});
var ArrayItem = /*#__PURE__*/memo(function (_ref) {
  var remove = _ref.remove,
      fields = _ref.fields,
      name = _ref.name,
      removeText = _ref.removeText,
      buttonDisabled = _ref.buttonDisabled,
      RemoveButtonProps = _ref.RemoveButtonProps,
      ArrayItemProps = _ref.ArrayItemProps;
  var formOptions = useFormApi();

  var _useStyles = useStyles(),
      removeStyle = _useStyles.remove;

  var editedFields = fields.map(function (field) {
    return _objectSpread(_objectSpread({}, field), field.name ? {
      name: "".concat(name, ".").concat(field.name)
    } : {
      name: name
    });
  });
  return /*#__PURE__*/React.createElement("div", ArrayItemProps, formOptions.renderForm(editedFields, formOptions), /*#__PURE__*/React.createElement(Button, _extends({
    disabled: buttonDisabled,
    renderIcon: Subtract32,
    id: "remove-".concat(name),
    kind: "danger",
    onClick: remove
  }, RemoveButtonProps, {
    className: clsx(removeStyle, RemoveButtonProps.className)
  }), removeText));
}, function (_ref2, _ref3) {
  var _prevRemove = _ref2.remove,
      prev = _objectWithoutProperties(_ref2, _excluded);

  var _nextRemove = _ref3.remove,
      next = _objectWithoutProperties(_ref3, _excluded2);

  return isEqual(prev, next);
});
ArrayItem.propTypes = {
  remove: PropTypes.func,
  fields: PropTypes.array,
  name: PropTypes.string,
  removeText: PropTypes.node,
  buttonDisabled: PropTypes.bool,
  RemoveButtonProps: PropTypes.object,
  ArrayItemProps: PropTypes.object
};
ArrayItem.defaultProps = {
  RemoveButtonProps: {},
  ArrayItemProps: {}
};

var FieldArray = function FieldArray(props) {
  var _useFieldApi = useFieldApi(prepareProps(props)),
      AddContainerProps = _useFieldApi.AddContainerProps,
      AddButtonProps = _useFieldApi.AddButtonProps,
      FormGroupProps = _useFieldApi.FormGroupProps,
      WrapperProps = _useFieldApi.WrapperProps,
      ArrayItemProps = _useFieldApi.ArrayItemProps,
      RemoveButtonProps = _useFieldApi.RemoveButtonProps,
      defaultItem = _useFieldApi.defaultItem,
      maxItems = _useFieldApi.maxItems,
      minItems = _useFieldApi.minItems,
      fields = _useFieldApi.fields,
      input = _useFieldApi.input,
      arrayValidator = _useFieldApi.arrayValidator,
      labelText = _useFieldApi.labelText,
      buttonLabels = _useFieldApi.buttonLabels,
      noItemsMessage = _useFieldApi.noItemsMessage,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount;

  var _useStyles2 = useStyles(),
      formGroup = _useStyles2.formGroup,
      addContainer = _useStyles2.addContainer,
      add = _useStyles2.add;

  var buttonLabelsFinal = _objectSpread({
    add: 'Add',
    remove: 'Remove'
  }, buttonLabels);

  var invalid = (meta.touched || validateOnMount) && !Array.isArray(meta.error) && (meta.error || meta.submitError);
  return /*#__PURE__*/React.createElement(FormGroup, _extends({
    legendText: labelText || '',
    invalid: Boolean(invalid),
    message: Boolean(invalid),
    messageText: invalid || ''
  }, FormGroupProps, {
    className: clsx(formGroup, FormGroupProps.className)
  }), /*#__PURE__*/React.createElement(FieldArrayFF, {
    name: input.name,
    validate: arrayValidator
  }, function (fieldArrayProps) {
    return /*#__PURE__*/React.createElement("div", WrapperProps, fieldArrayProps.fields.length === 0 && noItemsMessage, fieldArrayProps.fields.map(function (name, index) {
      return /*#__PURE__*/React.createElement(ArrayItem, {
        removeText: buttonLabelsFinal.remove,
        key: index,
        remove: function remove() {
          return fieldArrayProps.fields.remove(index);
        },
        name: name,
        fields: fields,
        buttonDisabled: minItems >= fieldArrayProps.fields.length,
        ArrayItemProps: ArrayItemProps,
        RemoveButtonProps: RemoveButtonProps
      });
    }), /*#__PURE__*/React.createElement("div", _extends({}, AddContainerProps, {
      className: clsx(addContainer, AddContainerProps.className)
    }), /*#__PURE__*/React.createElement(Button, _extends({
      disabled: fieldArrayProps.fields.length >= maxItems,
      renderIcon: AddAlt32,
      id: "add-".concat(input.name),
      onClick: function onClick() {
        return fieldArrayProps.fields.push(defaultItem);
      }
    }, AddButtonProps, {
      className: clsx(add, AddButtonProps.className)
    }), buttonLabelsFinal.add)));
  }));
};

FieldArray.propTypes = {
  noItemsMessage: PropTypes.node,
  maxItems: PropTypes.number,
  minItems: PropTypes.number,
  buttonLabels: PropTypes.shape({
    add: PropTypes.node,
    remove: PropTypes.node
  }),
  AddContainerProps: PropTypes.object,
  AddButtonProps: PropTypes.object,
  FormGroupProps: PropTypes.object,
  WrapperProps: PropTypes.object,
  ArrayItemProps: PropTypes.object,
  RemoveButtonProps: PropTypes.object,
  defaultItem: PropTypes.any,
  isRequired: PropTypes.bool,
  fields: PropTypes.array
};
FieldArray.defaultProps = {
  noItemsMessage: 'No items',
  maxItems: Infinity,
  minItems: 0,
  AddContainerProps: {},
  AddButtonProps: {},
  FormGroupProps: {},
  WrapperProps: {},
  ArrayItemProps: {},
  RemoveButtonProps: {}
};
export default FieldArray;
